@@ -31,11 +31,9 @@ class CheckResponseTime(nagiosplugin.Check):
                 'nagios.responsetime') as cookie:
             last_seen_date = cookie.get(default=datetime.datetime.min)
             stats = self.get_statistics(self.log_file, last_seen_date)
+            self.measures = self.convert_to_measures(stats)
             if stats.count:
-                self.measures = self.convert_to_measures(stats)
                 cookie.set(stats.last_date)
-            else:
-                self.measures = []
 
     def get_statistics(self, log_file, last_seen_date):
         logfile = nagios.responsetime.logfile.LogFile(log_file)
