@@ -53,11 +53,12 @@ class CheckResponseTimeTest(unittest.TestCase):
              for m in sorted(self.check.measures, key=lambda m: m.name)])
 
     def test_no_records_available_returns_no_performance(self):
+        from nagios.responsetime.logfile import Statistics
         with mock.patch.object(self.check, 'get_statistics') as get:
-            get.return_value = FakeStatistics()
-            get.return_value.count = 0
+            get.return_value = Statistics([])
             self.check.obtain_data()
-        self.assertEqual([], self.check.measures)
+        for m in self.check.measures:
+            self.assertEqual(0, m.value)
 
     def test_repeated_call_remembers_data_seen(self):
         self.check.log_file = mock.sentinel.log_file
