@@ -80,3 +80,12 @@ class StatisticsTest(unittest.TestCase):
         self.assertAlmostEqual(0.4, self.stats.stddev, 1)
         self.assertEqual(datetime.datetime(2011, 5, 17, 14, 4),
                          self.stats.last_date)
+
+    def test_single_entry_stddev_is_zero(self):
+        from nagios.responsetime.logfile import Record
+        from datetime import datetime
+        self.stats = nagios.responsetime.logfile.Statistics([
+            Record(date=datetime(2011, 5, 17, 14, 1), time=0.5)])
+        self.assertEqual(1, self.stats.count)
+        self.assertEqual(0.5, self.stats.mean)
+        self.assertEqual(0, self.stats.stddev)
